@@ -1,5 +1,4 @@
-/* kio.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -38,7 +37,6 @@ bool Kio::download(const KURL & from, const QString & to)
     KIO::Job *iojob = KIO::file_copy(from, to);
     connect( iojob, SIGNAL( result(KIO::Job*) ),
 	     SLOT( slotIOJobFinished( KIO::Job* )));
-
     // missing modal widget hack here.
     // I'd recommend using KIO::NetAccess instead (David).
     kapp->enter_loop();
@@ -94,7 +92,7 @@ bool Kiod::listDir(const QString &url, const QString &fname, bool subdirs)
     return FALSE;
 }
 
-void Kiod::slotListEntries( KIO::Job *job, const KIO::UDSEntryList& entries )
+void Kiod::slotListEntries( KIO::Job *, const KIO::UDSEntryList& entries )
 {
   long size = 0;
   QString text;
