@@ -1,5 +1,4 @@
-/* main.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -90,8 +89,6 @@ int main(int argc, char **argv)
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
   KApplication app;
   
-  setenv("LC_ALL", KGlobal::locale()->language().latin1(), 1);
-
   kpkg = 0;
   int j = 0;
 
