@@ -1,8 +1,29 @@
-//////////////////////////////////////////////////////////////         
-//      $Id: options.cpp,v 1.32 2002/09/16 14:39:35 toivo Exp $ 
-//
-// Author: Toivo Pedastse
-//
+/*
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include "../config.h"
 
 #include "kpackage.h"
@@ -12,14 +33,28 @@
 #include "cache.h"
 
 #include <qvbox.h>
-
+#include <qcheckbox.h>
 #include <klocale.h>
+#include <kdebug.h>
+#include <kurlrequester.h>
+#include <qframe.h>
+#include <qlabel.h>
+#include <qgroupbox.h>
+#include <qlayout.h>
+#include <qlineedit.h>
+#include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qtabdialog.h>
+#include <kcombobox.h>
+#include <klineedit.h>
+
+#include <findf.h>
 
 extern Opts *opts;
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 Options::Options(QWidget *parent)
-    : KDialogBase(Tabbed, i18n("Options"), Ok | Apply | Cancel, Ok, parent, 0, false){
+    : KDialogBase(Tabbed, i18n("Options"), Ok | Cancel, Ok, parent, 0, false){
 
     fRemote = false;
 
@@ -57,7 +92,7 @@ Options::Options(QWidget *parent)
 	  QGroupBox *box = new QGroupBox(2,Qt::Horizontal,kpinterface[i]->name, framet, "box");
 	  packageHandle[i] =  new QCheckBox(i18n("Enable"), box);
 	  connect(packageHandle[i], SIGNAL(clicked()), this, SLOT(scanLocates()));
-	  locate[i] = new QPushButton(i18n("Location of Packages..."),box);
+	  locate[i] = new QPushButton(i18n("Location of Packages"),box);
 	  connect(locate[i], SIGNAL(clicked()), kpinterface[i], SLOT(setLocation()));
 	} else {
 	  packageHandle[i] =  0;
@@ -67,9 +102,9 @@ Options::Options(QWidget *parent)
 
     {
       QVBox *page = addVBoxPage(i18n("Cac&he"));
-      
+
       bc = new QButtonGroup(page);
-      bc->setTitle(i18n("Cache Remote Package Directories"));
+      bc->setTitle(i18n("Cache Remote Package Folders"));
       connect( bc, SIGNAL(clicked(int)), SLOT(PDCache(int)) );
 
       QVBoxLayout* vc = new QVBoxLayout( bc, 15, 10, "vc");
@@ -100,6 +135,10 @@ Options::Options(QWidget *parent)
       pcache[2] = new QRadioButton(i18n("Never"),bp);
       vp->addWidget(pcache[2]);
 
+      QGroupBox* cd = new QGroupBox (1, Qt::Horizontal, i18n("Cache Folder"), page) ;
+      cd->setSizePolicy (QSizePolicy::Expanding, QSizePolicy::Fixed) ;
+
+      cachedir = new KURLRequester("", cd, "cachedir");
     }
 
     {
@@ -121,18 +160,17 @@ Options::Options(QWidget *parent)
       vf->addStretch();
     }
 
-    connect( this, SIGNAL(applyClicked()), SLOT(apply_slot()) );
     connect( this, SIGNAL(okClicked()), SLOT(apply_slot()) );
     connect( this, SIGNAL(closeClicked()), SLOT(cancel_slot()) );
     connect( this, SIGNAL(cancelClicked()), SLOT(cancel_slot()) );
 
     setValues();
-      
+
 }
 
 
 void Options::insHosts() {
-  kdDebug() << "insHosts " <<  "\n";
+  //  kdDebug() << "insHosts " <<  "\n";
   bool found = false;
   QString s = hosts->currentText();
 
@@ -141,15 +179,16 @@ void Options::insHosts() {
     if (s == hosts->text(i))
       found = true;
   }
-  
+
   if (!found)
     hosts->insertItem(hosts->currentText(), 0);
 }
 
 void Options::setValues() {
-  kdDebug() << "setValues:\n";
+  //  kdDebug() << "setValues:\n";
   DCache = dc = opts->DCache;
   PCache = pc = opts->PCache;
+  CacheDir = opts->CacheDir;
 
   hosts->clear();
   hosts->completionObject()->clear();
@@ -162,7 +201,7 @@ void Options::setValues() {
   if (!hostName.isEmpty()) {
     huse->setChecked(TRUE);
   }
-  //  kdDebug() << "C=" <<opts->hostList.count() << "\n"; 
+  //  kdDebug() << "C=" <<opts->hostList.count() << "\n";
 
   int i;
   for (i = 0; i < kpinterfaceN; i++)  {
@@ -174,6 +213,7 @@ void Options::setValues() {
 
   dcache[DCache]->setChecked(TRUE);
   pcache[PCache]->setChecked(TRUE);
+  cachedir->lineEdit()->setText(CacheDir);
 
   ssh->setChecked(opts->useSSH);
   valid->setChecked(opts->VerifyFL);
@@ -186,17 +226,22 @@ Options::~Options()
 
 void Options::scanLocates() {
   int i;
-  
+
   bool remote = huse->isChecked();
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       //      kdDebug() << i << " " << hostName << " " << kpinterface[i]->hasRemote << "\n";
-      if (remote && !(kpinterface[i]->hasRemote)) {
-	packageHandle[i]->setEnabled(false);
-	locate[i]->setEnabled(false);
+      if (remote) {
+	if (kpinterface[i]->hasRemote) {
+	  packageHandle[i]->setEnabled(true);
+	  locate[i]->setEnabled(true);
+	} else {
+	  packageHandle[i]->setEnabled(false);
+	  locate[i]->setEnabled(false);
+	}
       } else {
 	packageHandle[i]->setEnabled(true);
-	if (!remote && packageHandle[i]->isChecked()) {
+	if ( packageHandle[i]->isChecked()) {
 	  locate[i]->setEnabled(true);
 	} else {
 	  locate[i]->setEnabled(false);
@@ -206,25 +251,25 @@ void Options::scanLocates() {
   }
 }
 
-void Options::useRemote() 
+void Options::useRemote()
 {
   scanLocates();
 }
 
-void Options::restore() 
+void Options::restore()
 {
   show();
   fRemote = huse->isChecked();
 }
 
-void Options::cancel_slot() 
+void Options::cancel_slot()
 {
-  kdDebug() << "Cancel\n";
+  //  kdDebug() << "Cancel\n";
   opts->readSettings();
   setValues();
 }
 
- void Options::apply_slot() 
+void Options::apply_slot()
 {
   bool doReload = false;
   bool newHost  = false;
@@ -259,6 +304,8 @@ void Options::cancel_slot()
 
   opts->DCache = dc;
   opts->PCache = pc;
+  cachedir->lineEdit()->setText (QDir(cachedir->lineEdit()->text()).path().append("/")) ; // make sure that cache directory ends with "/"
+  opts->CacheDir = cachedir->lineEdit()->text() ;
 
   for (i = 0; i < kpinterfaceN; i++)  {
     if (packageHandle[i]) {
@@ -269,7 +316,9 @@ void Options::cancel_slot()
     }
   }
 
-   scanLocates();
+  if (kpackage->findialog)
+    kpackage->findialog->checkSearchAll();
+  scanLocates();
   opts->writeSettings();
 
   if (doReload) {
@@ -293,23 +342,23 @@ void Options::PPCache(int r)
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-Opts::Opts(QString initHost)
+Opts::Opts(const QString &initHost)
 {
-readSettings(initHost);
+    readSettings(initHost);
 }
 
 Opts::~Opts()
 {
 }
 
-void Opts::readSettings(QString initHost)
+void Opts::readSettings(const QString &initHost)
 {
-  
+
   KConfig *config = kapp->config();
 
   config->setGroup("Kpackage");
 
-  kdDebug() << "readSettings: " << initHost << "\n";
+  //  kdDebug() << "readSettings: " << initHost << "\n";
   hostList = config->readListEntry("Host_list");
   if (!initHost.isEmpty() && !hostList.contains(initHost)) {
     hostList.prepend(initHost);
@@ -327,10 +376,17 @@ void Opts::readSettings(QString initHost)
     kdDebug() << "PCache=" << PCache << "\n";
     PCache = 0;
   }
+  CacheDir = config->readPathEntry("Cache_Directory", QDir::homeDirPath() + "/.kpackage/");
 
   useSSH = config->readNumEntry("Use_SSH",0);
   VerifyFL = config->readNumEntry("Verify_File_List",1);
   PkgRead = config->readNumEntry("Read_Package_files",0);
+}
+
+void Opts::readLaterSettings()
+{
+  KConfig *config = kapp->config();
+  config->setGroup("Kpackage");
 
   int i;
   for (i = 0; i < kpinterfaceN; i++)  {
@@ -342,7 +398,7 @@ void Opts::readSettings(QString initHost)
 
 void Opts::writeSettings()
 {
-  
+
   KConfig *config = kapp->config();
 
   config->setGroup("Kpackage");
@@ -351,6 +407,7 @@ void Opts::writeSettings()
 
   config->writeEntry("Dir_Cache", DCache);
   config->writeEntry("Package_Cache", PCache);
+  config->writePathEntry("Cache_Directory", CacheDir);
 
   config->writeEntry("Use_SSH",useSSH );
   config->writeEntry("Verify_File_List",VerifyFL );
