@@ -1,5 +1,4 @@
-/* pkgOptions.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -148,13 +147,13 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
   resize(800, 400);
 }
 
-void pkgOptions::setup(packageInfo *p, QString type) {
+void pkgOptions::setup(packageInfo *p, const QString &type) {
   QPtrList<packageInfo> *pl = new QPtrList<packageInfo>;
   pl->append(p);
   setup(pl,type);
 }
 
-void pkgOptions::setup(QPtrList<packageInfo> *pl, QString)
+void pkgOptions::setup(QPtrList<packageInfo> *pl, const QString &)
 {
  QString s;
  modified = FALSE;
@@ -300,14 +299,15 @@ void pkgOptions::cancelButtonClicked()
     accept();
 }
 
-void pkgOptions::hideEvent ( QHideEvent *h ) {
+void pkgOptions::closeEvent ( QCloseEvent * e ) {
+  kdDebug() << "pkgOptions::QCloseEvent\n";
   terminate();
-
-  QWidget::hideEvent (h);
+   
+  QWidget::closeEvent (e);
 }
 
 void pkgOptions::showEvent ( QShowEvent *e ) {
-  //  kdDebug() << "SHOW\n";
+  //  kdDebug() << "pkgOptions::showEvent\n";
   getKeep();
 
   modified = FALSE;
