@@ -1,6 +1,4 @@
 /***************************************************************************
-                          OldView.cpp  -  description
-                             -------------------
     begin                : Sun Oct 3 1999
     copyright            : (C) 1997-2000 by Peter Putzer
     email                : putzer@kde.org
@@ -965,7 +963,7 @@ void KSVContent::multiplexEnabled (bool val)
       {
 	KMessageBox::information (kapp->mainWidget(),
 				  i18n ("<p>You do not have the right permissions "   \
-					"to edit your system's init configuration. </p>"     \
+					"to edit your system's init configuration. "     \
 					"However, you are free to browse the runlevels.</p>" \
 					"<p>If you really want to edit the "                 \
 					"configuration, either <strong>restart</strong> "    \
@@ -1039,8 +1037,7 @@ void KSVContent::openWith ()
   KURL url; url.setPath(static_cast<KSVItem*>(getOrigin()->currentItem())->filenameAndPath());
   KURL::List urls; urls.append (url);
 
-  static KFileOpenWithHandler* handler = new KFileOpenWithHandler();
-  handler->displayOpenWithDialog (urls);
+	KRun::displayOpenWithDialog (urls);
 
   kdDebug(3000) << "Opening with..." << endl;
 }
