@@ -1,6 +1,7 @@
 /*
  *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
- *  Maintained by Adriaan de Groot <groot@kde.org>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
+ *  Former maintainer: Adriaan de Groot <groot@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -18,39 +19,28 @@
  **/
 
 #include <errno.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <sys/types.h>
 #include <sys/file.h>
 #include <sys/stat.h>
-#include <pwd.h>
-#include <grp.h>
-#include <stdio.h>
-#include <string.h>
-#include <limits.h>
-
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
 
 #include <qdir.h>
 #include <qgroupbox.h>
 
+#include <kdebug.h>
 
-#include "globals.h"
 #include "kglobal_.h"
 #include "misc.h"
 
 #include "addUser.h"
 #include <kmessagebox.h>
 
-#ifdef _KU_QUOTA
-addUser::addUser(KUser *AUser, Quota *AQuota, QWidget *parent, const char *name, int isprep) :
-  propdlg(AUser, AQuota, parent, name, isprep) {
-#else
-addUser::addUser(KUser *AUser, QWidget *parent, const char *name, int isprep) :
-  propdlg(AUser, parent, name, isprep) {
-#endif
-
+addUser::addUser( KUser *AUser, bool useprivategroup,
+  QWidget *parent, const char *name ) :
+  propdlg( AUser, useprivategroup, parent, name )
+{
   QGroupBox *group = new QGroupBox(frontpage);
   group->setTitle(i18n("New Account Options"));
   QVBoxLayout *groupLayout = new QVBoxLayout(group, marginHint(), spacingHint());
@@ -59,23 +49,34 @@ addUser::addUser(KUser *AUser, QWidget *parent, const char *name, int isprep) :
   createhome = new QCheckBox(i18n("Create home folder"), group);
   createhome->setChecked(true);
   copyskel = new QCheckBox(i18n("Copy skeleton"), group);
-  usePrivateGroup = new QCheckBox(i18n("Use private group"), group);
   connect(createhome, SIGNAL(toggled(bool)), copyskel, SLOT(setEnabled(bool)));
   frontlayout->addMultiCellWidget(group, frontrow, frontrow, 0, 2);
+
+  if ( useprivategroup ) pbprigr->setEnabled( false );
 }
 
-void addUser::slotOk() {
-  QString tmp;
-  uint newuid;
-  tmp = leid->text();
-  newuid = tmp.toInt();
+void addUser::slotOk()
+{
+  KUser *user = mUsers.first();
 
-  if (kug->getUsers().lookup(newuid) != 0) {
-    err->addMsg(i18n("User with UID %1 already exists").arg(newuid));
-    err->display();
+  if ( !check() ) return;
+
+  mergeUser( user, user );
+
+  if ( ( user->getCaps() & KUser::Cap_POSIX ) && 
+    kug->getUsers().lookup( user->getUID() ) ) {
+    KMessageBox::sorry( 0, i18n("User with UID %1 already exists.").arg( user->getUID() ) );
     return;
   }
 
+  if ( ( kug->getUsers().getCaps() & KUsers::Cap_Samba ) && 
+     ( user->getCaps() & KUser::Cap_Samba ) ) {
+    if ( kug->getUsers().lookup_sam( user->getSID().getRID() ) ) {
+      KMessageBox::sorry( 0, i18n("User with RID %1 already exists.").arg( user->getSID().getRID() ) );
+      return;
+    }
+  }
+
   if (createhome->isChecked())
   {
     user->setCreateHome(true);
@@ -86,51 +87,56 @@ void addUser::slotOk() {
     user->setCopySkel(true);
   }
 
-  check();
-
   if (user->getCreateHome() && !checkHome())
      return;
 
   if (user->getCreateMailBox() && !checkMailBox())
      user->setCreateMailBox(false);
 
+  saveg();
   accept();
 }
 
-bool addUser::checkHome() {
+bool addUser::checkHome()
+{
+  KUser *user = mUsers.first();
+
   struct stat s;
   int r;
 
   QString h_dir = user->getHomeDir();
-  r = stat(QFile::encodeName(h_dir), &s);
+  r = stat( QFile::encodeName(h_dir), &s );
 
-  if ((r == -1) && (errno == ENOENT))
+  if ( (r == -1) && (errno == ENOENT) )
     return true;
 
   if (r == 0) {
     if (S_ISDIR(s.st_mode)) {
-       if (KMessageBox::
-         warningContinueCancel (0, i18n("Folder %1 already exists!\n%2 may become owner and permissions may change.\nDo you really want to use %3?").arg(h_dir).arg(user->getName()).arg(h_dir), QString::null, KStdGuiItem::cont()) == KMessageBox::Cancel)
-                  return false;
-            else
-                  return true;
-       } else
-	  err->addMsg(i18n("%1 is not a folder").arg(h_dir));
-  } else
-    err->addMsg(QString::fromLatin1("checkHome: stat: %1 ").arg(QString::fromLocal8Bit(strerror(errno))));
+       if ( KMessageBox::
+         warningContinueCancel ( 0,
+           i18n("Folder %1 already exists!\n%2 may become owner and permissions may change.\nDo you really want to use %3?").
+           arg(h_dir).arg(user->getName()).arg(h_dir), QString::null, KStdGuiItem::cont() ) == KMessageBox::Cancel )
 
-  err->display();
+         return false;
+       else
+         return true;
+    } else
+      KMessageBox::error( 0, i18n("%1 is not a folder.").arg(h_dir) );
+  } else
+    KMessageBox::error( 0, i18n("stat() failed on %1.").arg(h_dir) );
 
   return false;
 }
 
-bool addUser::checkMailBox() {
+bool addUser::checkMailBox()
+{
   QString mailboxpath;
+  KUser *user = mUsers.first();
 
   struct stat s;
   int r;
 
-  mailboxpath = QString::fromLatin1("%1/%2").arg(QFile::decodeName(MAIL_SPOOL_DIR)).arg(user->getName());
+  mailboxpath = QFile::decodeName(MAIL_SPOOL_DIR) + "/" + user->getName();
   r = stat(QFile::encodeName(mailboxpath), &s);
 
   if ((r == -1) && (errno == ENOENT))
@@ -138,16 +144,14 @@ bool addUser::checkMailBox() {
 
   if (r == 0)
     if (S_ISREG(s.st_mode))
-      err->addMsg(i18n("Mailbox %1 already exists (uid=%2)")
+      KMessageBox::error( 0, i18n("Mailbox %1 already exists (uid=%2).")
                  .arg(mailboxpath)
-                 .arg(s.st_uid));
+                 .arg(s.st_uid) );
     else
-      err->addMsg(i18n("%1 exists but is not a regular file")
-                 .arg(mailboxpath));
+      KMessageBox::error( 0, i18n("%1 exists but is not a regular file.")
+                 .arg(mailboxpath) );
   else
-    err->addMsg(QString::fromLatin1("checkMail: stat: %1 ").arg(QString::fromLocal8Bit(strerror(errno))));
-
-  err->display();
+    KMessageBox::error( 0, i18n("stat() failed on %1.").arg(mailboxpath) );
 
   return false;
 }
