@@ -56,6 +56,7 @@ KUser::KUser()
   s_warn    = 7;
   s_inact   = -1;
 //  s_flag    = 0;
+  caps = 0;
   isCreateHome = false;
   isCreateMailBox = false;
   isCopySkel = false;
@@ -73,6 +74,7 @@ KUser::KUser(const KUser *user)
 void KUser::copy(const KUser *user)
 {
   if ( user != this ) {
+    caps = user->caps;
     p_name = user->p_name;
     p_surname = user->p_surname;
     p_email = user->p_email;
@@ -106,6 +108,8 @@ void KUser::copy(const KUser *user)
     sam_profile = user->sam_profile;
     sam_homedrive = user->sam_homedrive;
     sam_homepath = user->sam_homepath;
+    sam_workstations = user->sam_workstations;
+    sam_domain = user->sam_domain;
     sid = user->sid;
     pgroup_sid = user->pgroup_sid;
 
@@ -122,6 +126,16 @@ KUser::~KUser()
 {
 }
 
+void KUser::setCaps( int data )
+{
+  caps = data;
+}
+
+int KUser::getCaps()
+{
+  return caps;
+}
+
 bool KUser::getDeleteHome()
 {
   return isDeleteHome;
@@ -305,6 +319,16 @@ const QString &KUser::getHomePath() const //sam_homepath;
   return sam_homepath;
 }
 
+const QString &KUser::getWorkstations() const //sam_workstation;
+{
+  return sam_workstations;
+}
+
+const QString &KUser::getDomain() const //sam_domain;
+{
+  return sam_domain;
+}
+
 const SID &KUser::getSID() const //sid,
 {
   return sid;
@@ -468,6 +492,16 @@ void KUser::setHomePath( const QString &data ) //sam_homepath;
   sam_homepath = data;
 }
 
+void KUser::setWorkstations( const QString &data ) //sam_workstation;
+{
+  sam_workstations = data;
+}
+
+void KUser::setDomain( const QString &data ) //sam_domain
+{
+  sam_domain = data;
+}
+
 void KUser::setSID( const SID &data ) //sid,
 {
   sid = data;
@@ -580,7 +614,7 @@ int KUser::createMailBox()
 {
   QString mailboxpath;
   int fd;
-  mailboxpath = QString::fromLatin1("%1/%2").arg(QFile::decodeName(MAIL_SPOOL_DIR)).arg(p_name);
+  mailboxpath = QFile::decodeName(MAIL_SPOOL_DIR) + "/" + p_name;
   if((fd = open(QFile::encodeName(mailboxpath), O_CREAT|O_EXCL|O_WRONLY,
                 S_IRUSR|S_IWUSR)) < 0) {
     if (errno != EEXIST)
@@ -629,7 +663,7 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath)
       continue;
 
     QString filename(s.filePath(name));
-    
+
     QFileInfo info(filename);
     mode = 0;
     if ( info.permission(QFileInfo::ReadOwner) ) mode |=  S_IRUSR;
@@ -641,11 +675,14 @@ void KUser::copyDir(const QString &srcPath, const QString &dstPath)
     if ( info.permission(QFileInfo::ReadOther) ) mode |=  S_IROTH;
     if ( info.permission(QFileInfo::WriteOther) ) mode |=  S_IWOTH;
     if ( info.permission(QFileInfo::ExeOther) ) mode |=  S_IXOTH;
-    
+
     if ( info.isSymLink() ) {
       QString link = info.readLink();
-      
-      symlink(QFile::encodeName(link),QFile::encodeName(d.filePath(name)));
+
+      if (symlink(QFile::encodeName(link),QFile::encodeName(d.filePath(name))) != 0) {
+        KMessageBox::error( 0, i18n("Error creating symlink %1.\nError: %2")
+                  .arg(d.filePath(s[i])).arg(QString::fromLocal8Bit(strerror(errno))) );
+      }
     } else if ( info.isDir() ) {
       QDir dir(filename);
 
@@ -741,7 +778,7 @@ int KUser::removeCrontabs()
   QString file;
   QString command;
 
-  file = QString::fromLatin1("/var/cron/tabs/%1").arg(p_name);
+  file = QFile::decodeName(CRONTAB_DIR) + "/" + p_name;
   if ( access(QFile::encodeName(file), F_OK) == 0 ) {
     command = QString::fromLatin1("crontab -u %1 -r").arg(KProcess::quote(p_name));
     if ( system(QFile::encodeName(command)) != 0 ) {
@@ -757,7 +794,7 @@ int KUser::removeMailBox()
 {
   QString file;
 
-  file = QString::fromLatin1("%1/%2").arg(QFile::decodeName(MAIL_SPOOL_DIR)).arg(p_name);
+  file = QFile::decodeName(MAIL_SPOOL_DIR) + "/" + p_name;
   if (remove(QFile::encodeName(file)) != 0) {
     KMessageBox::error( 0, i18n("Cannot remove mailbox %1.\nError: %2")
                 .arg(file).arg(QString::fromLocal8Bit(strerror(errno))) );
@@ -802,7 +839,8 @@ const QString &KUsers::getDOMSID() const
   return domsid;
 }
 
-void KUsers::fillGecos(KUser *user, const char *gecos)
+void KUsers::parseGecos( const char *gecos, QString &name, 
+  QString &field1, QString &field2, QString &field3 )
 {
   int no = 0;
   const char *s = gecos;
@@ -817,15 +855,25 @@ void KUsers::fillGecos(KUser *user, const char *gecos)
       val = QString::fromLocal8Bit(s, (int)(pos-s));
 
     switch(no) {
-      case 0: user->setFullName(val); break;
-      case 1: caps & Cap_BSD ? user->setOffice(val) : user->setOffice1(val); break;
-      case 2: caps & Cap_BSD ? user->setWorkPhone(val) : user->setOffice2(val); break;
-      case 3: caps & Cap_BSD ? user->setHomePhone(val) : user->setAddress(val); break;
+      case 0: name = val; break;
+      case 1: field1 = val; break;
+      case 2: field2 = val; break;
+      case 3: field3 = val; break;
     }
     if(pos == NULL) break;
     s = pos+1;
     no++;
   }
+}  
+
+void KUsers::fillGecos(KUser *user, const char *gecos)
+{
+  QString name,field1,field2,field3;
+  parseGecos( gecos, name, field1, field2, field3 );
+  user->setFullName( name );
+  caps & Cap_BSD ? user->setOffice( field1 ) : user->setOffice1( field1 );
+  caps & Cap_BSD ? user->setWorkPhone( field2 ) : user->setOffice2( field2 );
+  caps & Cap_BSD ? user->setHomePhone( field3 ) : user->setAddress( field3 );
 }
 
 bool KUsers::doCreate(KUser *user)
